<?php
/**
 * WordPress settings Start
 * 
 * @version 1.0.3
 * */
if (!class_exists('FakeCustomerBlockerWordPressSettings')) {

    class FakeCustomerBlockerWordPressSettings {

        var $setttings_parameters;
        var $settings_prefix;

        function __construct($parameters, $prefix) {

            $this->setttings_parameters = $parameters;
            $this->setttings_prefix = $prefix;
            add_action('admin_menu', array($this, 'add_menu_item'));
            add_action('init', array($this, 'process_form_parameters'));
        }

        function process_form_parameters() {
            $save_settings_field_for_wp = !empty($_POST['save_settings_field_for_wp']) ? $_POST['save_settings_field_for_wp'] : '';
            if (wp_verify_nonce($save_settings_field_for_wp, 'save_settings_action')) {
                $options = array();

                foreach ($_POST as $key => $value) {
                    $options[$key] = $value;
                }

                update_option($this->setttings_prefix . '_options', $options);
            }
        }

        function add_menu_item() {

            foreach ($this->setttings_parameters as $single_option) {

                if ($single_option['type'] == 'submenu') {
                    add_submenu_page(
                            $single_option['parent_slug'], $single_option['page_title'], $single_option['menu_title'], $single_option['capability'], $single_option['menu_slug'], array($this, 'show_settings_wp')
                    );
                }
                if ($single_option['type'] == 'option') {
                    add_options_page(
                            $single_option['page_title'], $single_option['menu_title'], $single_option['capability'], $single_option['menu_slug'], array($this, 'show_settings')
                    );
                }
            }
        }

        function show_settings_wp() {
            ?>
            <div class="wrap fcbwp-setting-div tw-bs4 fcb-globel-option">
                <h2><?php esc_html_e('Fake Customer Blocker Settings', FCB_DOMAIN); ?></h2>
                <hr/>
                <form class="form-horizontal" method="post" action="">
                    <?php
                    wp_nonce_field('save_settings_action', 'save_settings_field_for_wp');
                    $config = get_option($this->setttings_prefix . '_options');
                    $config_selected_states = !empty($config['fcb_selected_state']) ? $config['fcb_selected_state'] : array();
                    $config_selected_country = !empty($config['fcb_selected_country']) ? $config['fcb_selected_country'] : array();
                    ?>
                    <fieldset style='display:block'>
                        <?php
                        $out = '';

                        foreach ($this->setttings_parameters as $single_page) {
                            foreach ($single_page['parameters'] as $key => $value) {

                                switch ($value['type']) {
                                    case "separator":
                                        $out .= '
						<div class="lead">' . $value['title'] . '</div>
						';
                                        break;
                                    case "text":
                                        $data_val = (isset($config[$value['name']]) && $config[$value['name']] != '') ? esc_html(stripslashes($config[$value['name']])) : esc_html(stripslashes($value['default']));
                                        $out .= '
						<div class="form-group">
							<label class="control-label" for="' . $value['id'] . '">' . $value['title'] . '</label>

							  <input type="text"  class="form-control ' . $value['class'] . '"  name="' . $value['name'] . '" id="' . $value['id'] . '" placeholder="' . $value['placeholder'] . '" value="' . $data_val . '">
							  <p class="help-block">' . $value['sub_text'] . '</p>

						  </div>
						';
                                        break;
                                    case "select":

                                        $out .= '
						<div class="form-group">
							<label class="control-label" for="' . $value['id'] . '">' . $value['title'] . '</label>

							  <select  style="' . $value['style'] . '" class="form-control ' . $value['class'] . '" name="' . $value['name'] . '" id="' . $value['id'] . '">';
                                        foreach ($value['options'] as $k => $v) {
                                            $out .= '<option value="' . $k . '" ' . ( $config_selected_country == $k ? ' selected ' : ' ' ) . ' >' . $v . '</option> ';
                                        }
                                        $out .= '
							  </select>
							  <p class="help-block">' . $value['sub_text'] . '</p>
							</div>

						';
                                        break;
                                    case "checkbox":

                                        if (strpos($_SERVER['REQUEST_URI'], "fake_customer_blocker_for_wordpress")) {
                                            $out .= '
                                        <main class="form-group fcbwp-checkbox-div">
                                            <label class="control-label" for="' . $value['id'] . '">' . $value['title'] . '</label> 
                                                <aside>';

                                            foreach ($value['value'] as $k => $v) {
                                                $checkbox_select_array = (isset($config['fcbwp-check-enable-for'])) ? $config['fcbwp-check-enable-for'] : array();
                                                
                                                if ($k == 'Ninja_Forms' && !class_exists('Ninja_Forms')) {
                                                    $out .= '  <label class="checkbox">
                                                        <input  class="' . $value['class'] . '" type="checkbox" name="' . $value['name'] . '[]" id="' . $value['id'] . '" value="' . $k . '" ' . (@in_array($k, $checkbox_select_array) ? ' checked ' : ' ') . '  disabled> &nbsp;
                                                        ' . $v . '                                                                                                                          
                                                        <p class="help-block">' . $value['sub_text'] . '</p>
                                                    </label>';
                                                } else if ($k == 'WPCF7' && !class_exists('WPCF7')) {
                                                    $out .= '  <label class="checkbox">
                                                        <input  class="' . $value['class'] . '" type="checkbox" name="' . $value['name'] . '[]" id="' . $value['id'] . '" value="' . $k . '" ' . (@in_array($k, $checkbox_select_array) ? ' checked ' : ' ') . '  disabled> &nbsp;
                                                        ' . $v . '                                                                                                                          
                                                        <p class="help-block">' . $value['sub_text'] . '</p>
                                                    </label>';
                                                }
                                                elseif ($k == 'EDD' && !class_exists('Easy_Digital_Downloads')) {
                                                    $out .= '  <label class="checkbox">
                                                        <input  class="' . $value['class'] . '" type="checkbox" name="' . $value['name'] . '[]" id="' . $value['id'] . '" value="' . $k . '" ' . (@in_array($k, $checkbox_select_array) ? ' checked ' : ' ') . '  disabled> &nbsp;
                                                        ' . $v . '                                                                                                                          
                                                        <p class="help-block">' . $value['sub_text'] . '</p>
                                                    </label>';
                                                } else if ($k == 'WC' && !class_exists('WooCommerce')) {

                                                    $out .= '  <label class="checkbox">
                                                            <input  class="' . $value['class'] . '" type="checkbox" name="' . $value['name'] . '[]" id="' . $value['id'] . '" value="' . $k . '" ' . (@in_array($k, $checkbox_select_array) ? ' checked ' : ' ') . ' disabled > &nbsp;
                                                            ' . $v . '                                                                                                                          
                                                            <p class="help-block">' . $value['sub_text'] . '</p>
                                                        </label>';
                                                } else {
                                                    $out .= '  <label class="checkbox">
                                                            <input  class="' . $value['class'] . '" type="checkbox" name="' . $value['name'] . '[]" id="' . $value['id'] . '" value="' . $k . '" ' . (@in_array($k, $checkbox_select_array) ? ' checked ' : ' ') . ' > &nbsp;
                                                            ' . $v . '                                                                                                                          
                                                            <p class="help-block">' . $value['sub_text'] . '</p>
                                                        </label>';
                                                }
                                            }
                                            $out .= ' <HR> </aside>
                                            </main> ';
                                        }
                                        break;
                                    case "radio":
                                        $out .= '
						<div class="form-group">
							<label class="control-label" for="' . $value['id'] . '">' . $value['title'] . '</label>';
                                        foreach ($value['options'] as $k => $v) {
                                            $out .= '
									<label class="radio">
										<input  class="' . $value['class'] . '" type="radio" name="' . $value['name'] . '" id="' . $value['id'] . '" value="' . $k . '" ' . ( $config[$value['name']] == $k ? ' checked ' : '' ) . ' >&nbsp;
										' . $v . '
										<p class="help-block">' . $value['sub_text'] . '</p>
									  </label> ';
                                        }
                                        $out .= '</div>';
                                        break;
                                    case "textarea":
                                        $data_val = (isset($config[$value['name']]) && $config[$value['name']] != '') ? esc_html(stripslashes($config[$value['name']])) : '';
                                        $out .= '
						<div class="form-group check-globel-depend">
							<label class="control-label" for="' . $value['id'] . '">' . $value['title'] . '</label>

							  <textarea style="' . $value['style'] . '" class="form-control ' . $value['class'] . '" name="' . $value['name'] . '" id="' . $value['id'] . '" placeholder="' . $value['placeholder'] . '" rows="' . $value['rows'] . '">' . $data_val . '</textarea>
							  <p class="help-block">' . $value['sub_text'] . '</p>

						  </div>
						';
                                        break;
                                    case "multiselect":
                                        if ($value['class'] == "multiselect-states") {
                                            $out .= '
                        <div class="form-group">
                            <label class="control-label" for="' . $value['id'] . '">' . $value['title'] . '</label>

                                <select  multiple="multiple" style="' . $value['style'] . '" class="form-control ' . $value['class'] . '" name="' . $value['name'] . '[]" id="' . $value['id'] . '">';
                                            foreach ($value['options'] as $k => $state_array) {
                                                foreach ($state_array as $state_k => $state_v) {
                                                    $out .= '<option value="' . $state_k . '" ' . ( @in_array($state_k, $config_selected_states) ? ' selected ' : ' ' ) . ' >' . $state_v . '</option> ';
                                                }
                                            }
                                            $out .= '
                                </select>
							  <p class="help-block">' . $value['sub_text'] . '</p>

						  </div>
						';
                                            break;
                                        } else {
                                            $out .= '
                            <div class="form-group">
                                <label class="control-label" for="' . $value['id'] . '">' . $value['title'] . '</label>
    
                                    <select  multiple="multiple" style="' . $value['style'] . '" class="form-control ' . $value['class'] . '" name="' . $value['name'] . '[]" id="' . $value['id'] . '">';
                                            foreach ($value['options'] as $country_k => $country_v) {
                                                $out .= '<option value="' . $country_k . '" ' . ( @in_array($country_k, $config_selected_country) ? ' selected ' : ' ' ) . ' >' . $country_v . '</option> ';
                                            }
                                            $out .= '
                                    </select>
                                  <p class="help-block">' . $value['sub_text'] . '</p>
    
                              </div>
                            ';
                                            break;
                                        }
                                }
                            }
                        }
                        echo $out;
                        ?>
                        <div class="form-actions">
                            <button type="submit" class="btn btn-primary"><?php esc_html_e('Save Settings', FCB_DOMAIN); ?></button>
                        </div>
                    </fieldset>
                </form>
            </div>
            <?php
        }

    }

}

/**
 * Return filed array
 * 
 * @version 1.0.3
 * */
if (!function_exists('wp_setting_options')) {

    function wp_setting_options() {

        /**
         * incude Country and States array
         * */
        include 'country.php';
        include 'states.php';

        //add option in backend 
        $config_big = array(
            array(
                'type' => 'submenu',
                'parent_slug' => 'options-general.php',
                'page_title' => __('Fake Customer Blocker', FCB_DOMAIN),
                'menu_title' => __('Fake Customer Blocker', FCB_DOMAIN),
                'capability' => 'edit_published_posts',
                'menu_slug' => 'fake_customer_blocker_for_wordpress',
                'parameters' => array(
                    array(
                        'name' => 'fcbwp-check-enable-for',
                        'type' => 'checkbox',
                        'title' => __('Enable for :', FCB_DOMAIN),
                        'value' => array(
                            'WC' => __('WooCommerce', FCB_DOMAIN),
                            'EDD' => __('Easy Digital Downloads', FCB_DOMAIN),
                            'WP' => __('WordPress', FCB_DOMAIN),
                            'WPCF7' => __('Contact Form 7', FCB_DOMAIN),
                        ),
                        'class' => '',
                        'style' => 'min-width:300px;',
                        'sub_text' => '',
                        'id' => '',
                        'default' => __('WP', FCB_DOMAIN),
                    ),
                    array(
                        'id' => '',
                        'class' => '',
                        'rows' => '',
                        'name' => 'domain_list_for_globel',
                        'type' => 'textarea',
                        'title' => __('Global Banned Domains and Emails', FCB_DOMAIN),
                        'placeholder' => __('armyspy.com&#x0a;cuvox.de&#x0a;xyz@gmail.com', FCB_DOMAIN),
                        'sub_text' => __('Enter Domain / Email one per line', FCB_DOMAIN),
                        'style' => 'height:300px;'
                    ),
                    array(
                        'id' => '',
                        'class' => '',
                        'rows' => '',
                        'name' => 'globel_email_message',
                        'type' => 'textarea',
                        'title' => __('Global Message For Email', FCB_DOMAIN),
                        'placeholder' => __('Sorry, you can not use any fake email addresses to make spam orders with the site. Try real email addresses like Gmail, Yahoo, etc.', FCB_DOMAIN),
                        'default' => __('Sorry, you can not use any fake email addresses to make spam orders with the site. Try real email addresses like Gmail, Yahoo, etc.', FCB_DOMAIN),
                        'sub_text' => __('Enter message text that will show on fronend with checkout page for baned domains.', FCB_DOMAIN),
                        'style' => 'height:100px;'
                    ),
                )
            )
        );

        return $config_big;
    }

}

$this->locale = 'fcb_wp';

new FakeCustomerBlockerWordPressSettings(wp_setting_options(), $this->locale);
// WordPress settings End 

/**
 * EDD settings Start
 * 
 * @version 1.0.3
 * */
if (!class_exists('FakeCustomerBlockerEDDSettings')) {

    class FakeCustomerBlockerEDDSettings {

        var $setttings_parameters;
        var $settings_prefix;

        function __construct($parameters, $prefix) {
            $this->setttings_parameters = $parameters;
            $this->setttings_prefix = $prefix;
            add_action('admin_menu', array($this, 'add_menu_item'));
            add_action('init', array($this, 'process_form_parameters'));
        }

        function process_form_parameters() {
            $save_settings_field_for_edd = !empty($_POST['save_settings_field_for_edd']) ? $_POST['save_settings_field_for_edd'] : '';
            if (wp_verify_nonce($save_settings_field_for_edd, 'save_settings_action')) {
                $options = array();
                foreach ($_POST as $key => $value) {
                    $options[$key] = $value;
                }

                update_option($this->setttings_prefix . '_options', $options);
            }
        }

        function add_menu_item() {

            foreach ($this->setttings_parameters as $single_option) {

                if ($single_option['type'] == 'submenu') {
                    $config = get_option('fcb_wp_options');
                    $check_enable_array = (isset($config['fcbwp-check-enable-for'])) ? $config['fcbwp-check-enable-for'] : array();
                    foreach ($check_enable_array as $selected_permission) {
                        if ($selected_permission == 'EDD') {
                            add_submenu_page(
                                    $single_option['parent_slug'], $single_option['page_title'], $single_option['menu_title'], $single_option['capability'], $single_option['menu_slug'], array($this, 'show_settings_edd')
                            );
                        }
                    }
                }
                if ($single_option['type'] == 'option') {
                    add_options_page(
                            $single_option['page_title'], $single_option['menu_title'], $single_option['capability'], $single_option['menu_slug'], array($this, 'show_settings_edd')
                    );
                }
            }
        }

        function show_settings_edd() {
            ?>
            <div class="wrap tw-bs4">
                <h2><?php esc_html_e('Fake Customer Blocker Settings', FCB_DOMAIN); ?></h2>
                <hr/>
                <form class="form-horizontal" method="post" action="">
                    <?php
                    wp_nonce_field('save_settings_action', 'save_settings_field_for_edd');
                    $config = get_option($this->setttings_prefix . '_options');
                    $config_selected_states = !empty($config['fcb_edd_selected_state']) ? $config['fcb_edd_selected_state'] : array();
                    $config_selected_country = !empty($config['fcb_edd_selected_country']) ? $config['fcb_edd_selected_country'] : array();
                    ?>
                    <fieldset>
                        <?php
                        $out = '';

                        foreach ($this->setttings_parameters as $single_page) {
                            foreach ($single_page['parameters'] as $key => $value) {

                                switch ($value['type']) {
                                    case "textarea":
                                        $data_val = (isset($config[$value['name']]) && $config[$value['name']] != '') ? esc_html(stripslashes($config[$value['name']])) : '';
                                        $config_wp = get_option('fcb_wp_options');

                                        if ($value['name'] == 'email_message_for_edd' && in_array('WP', $config_wp['fcbwp-check-enable-for'])) {
                                            $out .= '
                                <div class="form-group">
                                    <label class="control-label" for="' . $value['id'] . '">' . $value['title'] . '</label>
                                    <textarea style="' . $value['style'] . '" class="form-control ' . $value['class'] . '" name="' . $value['name'] . '" id="' . $value['id'] . '" placeholder="' . $value['placeholder'] . '" rows="' . $value['rows'] . '" disabled>' . $data_val . '</textarea>
                                   <h6 style="color:#17a2b8">'. esc_html_e('In your Settings > Fake Customer Blocker, You enable the WordPress option. So, you can not write a message. It will display the message that you set in Settings > Fake Customer Blocker > Global Message For Email.', FCB_DOMAIN).'</h6>
                                </div>';
                                        } else {

                                            $out .= '
                            <div class="form-group">
                                <label class="control-label" for="' . $value['id'] . '">' . $value['title'] . '</label>
    
                                  <textarea style="' . $value['style'] . '" class="form-control ' . $value['class'] . '" name="' . $value['name'] . '" id="' . $value['id'] . '" placeholder="' . $value['placeholder'] . '" rows="' . $value['rows'] . '">' . $data_val . '</textarea>
                                  <p class="help-block">' . $value['sub_text'] . '</p>
    
                              </div>';
                                        }
                                        break;
                                }
                            }
                        }
                        echo $out;
                        ?>
                        <div class="form-actions">
                            <button type="submit" class="btn btn-primary"><?php esc_html_e('Save Settings', FCB_DOMAIN); ?></button>
                        </div>
                    </fieldset>
                </form>
            </div>
            <?php
        }

    }

}

/**
 * Return filed array
 * 
 * @version 1.0.3
 * */
if (!function_exists('config_big_edd')) {

    function config_big_edd() {
        /*
         * add option in backend 
         */
        $config_big_edd = array(
            array(
                'type' => 'submenu',
                'parent_slug' => 'edit.php?post_type=download',
                'page_title' => __('Fake Customer Blocker', FCB_DOMAIN),
                'menu_title' => __('Fake Customer Blocker', FCB_DOMAIN),
                'capability' => 'edit_published_posts',
                'menu_slug' => 'fake_customer_blocker_edd',
                'parameters' => array(
                    array(
                        'id' => '',
                        'class' => '',
                        'rows' => '',
                        'name' => 'domain_list_for_edd',
                        'type' => 'textarea',
                        'title' => __('Banned Domains and Emails', FCB_DOMAIN),
                        'placeholder' => __('armyspy.com&#x0a;cuvox.de&#x0a;xyz@gmail.com', FCB_DOMAIN),
                        'sub_text' => __('Enter Domain / Email one per line', FCB_DOMAIN),
                        'style' => 'height:300px;'
                    ),
                    array(
                        'id' => '',
                        'class' => '',
                        'rows' => '',
                        'name' => 'email_message_for_edd',
                        'type' => 'textarea',
                        'title' => __('Checkout Page Message', FCB_DOMAIN),
                        'placeholder' => __('Sorry, you can not use any fake email addresses to make spam orders with the site. Try real email addresses like Gmail, Yahoo, etc.', FCB_DOMAIN),
                        'sub_text' => __('Enter the text message here. It will show on the frontend via the checkout page for banned Domains / Emails.', FCB_DOMAIN),
                        'style' => 'height:100px;'
                    ),
                )
            )
        );
        return $config_big_edd;
    }

}

$this->locale = 'fcb_edd';

new FakeCustomerBlockerEDDSettings(config_big_edd(), $this->locale);
// EDD settings End

/**
 * WooCommrece settings Start
 * 
 * @version 1.0.0
 * */
if (!class_exists('FakeCustomerBlockerSettings')) {


    class FakeCustomerBlockerSettings {

        var $setttings_parameters;
        var $settings_prefix;

        function __construct($parameters, $prefix) {

            $this->setttings_parameters = $parameters;
            $this->setttings_prefix = $prefix;
            add_action('admin_menu', array($this, 'add_menu_item'));
            add_action('init', array($this, 'process_form_parameters_for_woocommerce'));
        }

        function process_form_parameters_for_woocommerce() {
            $save_settings_field_wc = !empty($_POST['save_settings_field_wc']) ? $_POST['save_settings_field_wc'] : '';
            if (wp_verify_nonce($save_settings_field_wc, 'save_settings_action')) {

                $options = array();
                foreach ($_POST as $key => $value) {
                    $options[$key] = $value;
                }
                update_option($this->setttings_prefix . '_options', $options);
            }
        }

        function add_menu_item() {

            foreach ($this->setttings_parameters as $single_option) {
                if ($single_option['type'] == 'submenu') {
                    $config = get_option('fcb_wp_options');

                    $check_enable_array = (isset($config['fcbwp-check-enable-for'])) ? $config['fcbwp-check-enable-for'] : array();
                    foreach ($check_enable_array as $selected_permission) {
                        if ($selected_permission == 'WC') {
                            add_submenu_page(
                                    $single_option['parent_slug'], $single_option['page_title'], $single_option['menu_title'], $single_option['capability'], $single_option['menu_slug'], array($this, 'show_settings_wc')
                            );
                        }
                    }
                }
                if ($single_option['type'] == 'option') {
                    add_options_page(
                            $single_option['page_title'], $single_option['menu_title'], $single_option['capability'], $single_option['menu_slug'], array($this, 'show_settings_wc')
                    );
                }
            }
        }

        function show_settings_wc() {
            ?>
            <div class="wrap tw-bs4">
                <h2><?php esc_html_e('Fake Customer Blocker Settings', FCB_DOMAIN); ?></h2>
                <hr/>
                <form class="form-horizontal" method="post" action="">
                    <?php
                    wp_nonce_field('save_settings_action', 'save_settings_field_wc');
                    $config = get_option($this->setttings_prefix . '_options');
                    $config_selected_states = !empty($config['fcb_selected_state']) ? $config['fcb_selected_state'] : array();
                    $config_selected_country = !empty($config['fcb_selected_country']) ? $config['fcb_selected_country'] : array();
                    ?>
                    <fieldset>
                        <?php
                        $out = '';

                        foreach ($this->setttings_parameters as $single_page) {
                            foreach ($single_page['parameters'] as $key => $value) {

                                switch ($value['type']) {
                                    case "separator":
                                        $out .= '
						<div class="lead">' . $value['title'] . '</div>
						';
                                        break;
                                    case "text":
                                        $data_val = (isset($config[$value['name']]) && $config[$value['name']] != '') ? esc_html(stripslashes($config[$value['name']])) : esc_html(stripslashes($value['default']));
                                        $out .= '
						<div class="form-group">
							<label class="control-label" for="' . $value['id'] . '">' . $value['title'] . '</label>

							  <input type="text"  class="form-control ' . $value['class'] . '"  name="' . $value['name'] . '" id="' . $value['id'] . '" placeholder="' . $value['placeholder'] . '" value="' . $data_val . '">
							  <p class="help-block">' . $value['sub_text'] . '</p>

						  </div>
						';
                                        break;
                                    case "select":

                                        $out .= '
						<div class="form-group">
							<label class="control-label" for="' . $value['id'] . '">' . $value['title'] . '</label>

							  <select  style="' . $value['style'] . '" class="form-control ' . $value['class'] . '" name="' . $value['name'] . '" id="' . $value['id'] . '">';
                                        foreach ($value['options'] as $k => $v) {
                                            $out .= '<option value="' . $k . '" ' . ( $config_selected_country == $k ? ' selected ' : ' ' ) . ' >' . $v . '</option> ';
                                        }
                                        $out .= '
							  </select>
							  <p class="help-block">' . $value['sub_text'] . '</p>
							</div>

						';
                                        break;
                                    case "checkbox":
                                        $out .= '
						<div class="form-group">
							<label class="control-label" for="' . $value['id'] . '">' . $value['title'] . '</label>

							  <label class="checkbox">
								<input  class="' . $value['class'] . '" type="checkbox" name="' . $value['name'] . '" id="' . $value['id'] . '" value="on" ' . ( $config[$value['name']] == 'on' ? ' checked ' : '' ) . ' > &nbsp;
								' . $value['text'] . '
								<p class="help-block">' . $value['sub_text'] . '</p>
							  </label>

						  </div>
						';
                                        break;
                                    case "radio":
                                        $out .= '
						<div class="form-group">
							<label class="control-label" for="' . $value['id'] . '">' . $value['title'] . '</label>';
                                        foreach ($value['options'] as $k => $v) {
                                            $out .= '
									<label class="radio">
										<input  class="' . $value['class'] . '" type="radio" name="' . $value['name'] . '" id="' . $value['id'] . '" value="' . $k . '" ' . ( $config[$value['name']] == $k ? ' checked ' : '' ) . ' >&nbsp;
										' . $v . '
										<p class="help-block">' . $value['sub_text'] . '</p>
									  </label> ';
                                        }
                                        $out .= '

						  </div>
						';
                                        break;
                                    case "textarea":

                                        $data_val = (isset($config[$value['name']]) && $config[$value['name']] != '') ? esc_html(stripslashes($config[$value['name']])) : '';

                                        $config_wp = get_option('fcb_wp_options');
                                        if ($value['name'] == 'email_message' && in_array('WP', $config_wp['fcbwp-check-enable-for'])) {
                                            $out .= '
                                <div class="form-group">
                                    <label class="control-label" for="' . $value['id'] . '">' . $value['title'] . '</label>
        
                                      <textarea style="' . $value['style'] . '" class="form-control ' . $value['class'] . '" name="' . $value['name'] . '" id="' . $value['id'] . '" placeholder="' . $value['placeholder'] . '" rows="' . $value['rows'] . '" disabled>' . $data_val . '</textarea>
                                     <h6 style="color:#17a2b8">'. esc_html_e('In your Settings > Fake Customer Blocker, You enable the WordPress option. So, you can not write a message. It will display the message that you set in Settings > Fake Customer Blocker > Global Message For Email.', FCB_DOMAIN).'</h6>
        
                                  </div>
                                ';
                                        } else {
                                            $out .= '
                            <div class="form-group">
                                <label class="control-label" for="' . $value['id'] . '">' . $value['title'] . '</label>
    
                                  <textarea style="' . $value['style'] . '" class="form-control ' . $value['class'] . '" name="' . $value['name'] . '" id="' . $value['id'] . '" placeholder="' . $value['placeholder'] . '" rows="' . $value['rows'] . '">' . $data_val . '</textarea>
                                  <p class="help-block">' . $value['sub_text'] . '</p>
    
                              </div>
                            ';
                                        }
                                        break;
                                    case "multiselect":
                                        if ($value['class'] == "multiselect-states") {
                                            $out .= '
                        <div class="form-group">
                            <label class="control-label" for="' . $value['id'] . '">' . $value['title'] . '</label>

                                <select  multiple="multiple" style="' . $value['style'] . '" class="form-control ' . $value['class'] . '" name="' . $value['name'] . '[]" id="' . $value['id'] . '"> ';
                                            foreach ($value['options'] as $k => $state_array) {
                                                foreach ($state_array as $state_k => $state_v) {
                                                    $out .= '<option value="' . $state_k . '" ' . ( @in_array($state_k, $config_selected_states) ? ' selected ' : ' ' ) . ' >' . $state_v . '</option> ';
                                                }
                                            }
                                            $out .= '
                                </select>
							  <p class="help-block">' . $value['sub_text'] . '</p>

						  </div>
						';
                                            break;
                                        } else {
                                            $out .= '
                            <div class="form-group">
                                <label class="control-label" for="' . $value['id'] . '">' . $value['title'] . '</label>
    
                                    <select  multiple="multiple" style="' . $value['style'] . '" class="form-control ' . $value['class'] . '" name="' . $value['name'] . '[]" id="' . $value['id'] . '">';
                                            foreach ($value['options'] as $country_k => $country_v) {
                                                $out .= '<option value="' . $country_k . '" ' . ( @in_array($country_k, $config_selected_country) ? ' selected ' : ' ' ) . ' >' . $country_v . '</option> ';
                                            }
                                            $out .= '
                                    </select>
                                  <p class="help-block">' . $value['sub_text'] . '</p>
    
                              </div>
                            ';
                                            break;
                                        }
                                }
                            }
                        }
                        echo $out;
                        ?>
                        <div class="form-actions">
                            <button type="submit" class="btn btn-primary"><?php esc_html_e('Save Settings', FCB_DOMAIN); ?></button>
                        </div>
                    </fieldset>
                </form>
            </div>
            <?php
        }

    }

}

/**
 * Return filed array
 * 
 * @version 1.0.0
 * */
if (!function_exists('config_big')) {

    function config_big() {

        /**
         * incude Country and States array
         * */
        include 'country.php';
        include 'states.php';

        //add option in backend 
        $config_big = array(
            array(
                'type' => 'submenu',
                'parent_slug' => 'woocommerce',
                'page_title' => __('Fake Customer Blocker', FCB_DOMAIN),
                'menu_title' => __('Fake Customer Blocker', FCB_DOMAIN),
                'capability' => 'edit_published_posts',
                'menu_slug' => 'fake_customer_blocker',
                'parameters' => array(
                    array(
                        'name' => 'fcb_selected_country',
                        'type' => 'multiselect',
                        'title' => __('Banned Countries', FCB_DOMAIN),
                        'options' => $country_array,
                        'class' => 'multiselect-country',
                        'style' => 'min-width:300px;',
                        'sub_text' => __('Select Country you want to block', FCB_DOMAIN),
                        'id' => 'fcb-selected-country',
                        'default' => 'AF',
                    ),
                    array(
                        'id' => '',
                        'class' => '',
                        'rows' => '',
                        'name' => 'country_message',
                        'type' => 'textarea',
                        'title' => __('Checkout Page Message for Country', FCB_DOMAIN),
                        'placeholder' => __('Selected Country is blocked by Admin', FCB_DOMAIN),
                        'default' => __('Selected Country is blocked by Admin', FCB_DOMAIN),
                        'sub_text' => __('Enter the text message here. It will show on the frontend via the checkout page for banned Country.', FCB_DOMAIN),
                        'style' => 'height:100px;'
                    ),
                    array(
                        'name' => 'fcb_selected_state',
                        'type' => 'multiselect',
                        'title' => __('Banned States', FCB_DOMAIN),
                        'options' => $states_array,
                        'class' => 'multiselect-states',
                        'style' => 'min-width:300px;',
                        'validate' => array('state'),
                        'sub_text' => __('Select State you want to banned', FCB_DOMAIN),
                        'id' => 'fcb-selected-state',
                        'default' => 'AF',
                    ),
                    array(
                        'id' => '',
                        'class' => '',
                        'rows' => '',
                        'name' => 'state_message',
                        'type' => 'textarea',
                        'title' => __('Checkout Page Message for State', FCB_DOMAIN),
                        'placeholder' => __('Selected State is blocked by Admin', FCB_DOMAIN),
                        'default' => __('Selected State is blocked by Admin', FCB_DOMAIN),
                        'sub_text' => __('Enter the text message here. It will show on the frontend via the checkout page for banned State.', FCB_DOMAIN),
                        'style' => 'height:100px;'
                    ),
                    array(
                        'id' => '',
                        'class' => '',
                        'rows' => '',
                        'name' => 'pin_code_list',
                        'type' => 'textarea',
                        'title' => __('Banned Pincodes', FCB_DOMAIN),
                        'placeholder' => __('123456&#x0a;005252', FCB_DOMAIN),
                        'default' => '123456&#x0a;005252',
                        'sub_text' => __('Enter Pincodes. One per line', FCB_DOMAIN),
                        'style' => 'height:100px;'
                    ),
                    array(
                        'id' => '',
                        'class' => '',
                        'rows' => '',
                        'name' => 'pin_code_message',
                        'type' => 'textarea',
                        'title' => __('Checkout Page Message for Pincode', FCB_DOMAIN),
                        'placeholder' => __('Your Pincode is blocked by Admin', FCB_DOMAIN),
                        'default' => __('Your Pincode is blocked by Admin', FCB_DOMAIN),
                        'sub_text' => __('Enter the text message here. It will show on the frontend via the checkout page for banned Pincode.', FCB_DOMAIN),
                        'style' => 'height:100px;'
                    ),
                    array(
                        'id' => '',
                        'class' => '',
                        'rows' => '',
                        'name' => 'domain_list',
                        'type' => 'textarea',
                        'title' => __('Banned Domains and Emails', FCB_DOMAIN),
                        'placeholder' => __('armyspy.com&#x0a;cuvox.de&#x0a;xyz@gmail.com', FCB_DOMAIN),
                        'sub_text' => __('Enter Domain / Email one per line', FCB_DOMAIN),
                        'style' => 'height:300px;'
                    ),
                    array(
                        'id' => '',
                        'class' => '',
                        'rows' => '',
                        'name' => 'email_message',
                        'type' => 'textarea',
                        'title' => __('Checkout Page Message', FCB_DOMAIN),
                        'placeholder' => __('Sorry, you can not use any fake email addresses to make spam orders with the site. Try real email addresses like Gmail, Yahoo, etc.', FCB_DOMAIN),
                        'default' => __('Sorry, you can not use any fake email addresses to make spam orders with the site. Try real email addresses like Gmail, Yahoo, etc.', FCB_DOMAIN),
                        'sub_text' => __('Enter message text that will show on fronend with checkout page for baned domains.', FCB_DOMAIN),
                        'style' => 'height:100px;'
                    ),
                    array(
                        'id' => '',
                        'class' => '',
                        'rows' => '',
                        'name' => 'email_profile',
                        'type' => 'textarea',
                        'title' => __('Register/ Edit Profile Page Message', FCB_DOMAIN),
                        'placeholder' => __('Please update your email address to any real email address. Until that time your downloadable product\'s downloads are blocked by the site admin.', FCB_DOMAIN),
                        'default' => __('Please update your email address to any real email address. Until that time your downloadable product\'s downloads are blocked by the site admin.', FCB_DOMAIN),
                        'sub_text' => __('Enter message text that will show on my account page and guide them to update their email address or required details instead of fake details.', FCB_DOMAIN),
                        'style' => 'height:100px;'
                    ),
                    array(
                        'id' => '',
                        'class' => '',
                        'rows' => '',
                        'name' => 'email_downloads',
                        'type' => 'textarea',
                        'title' => __('Downloads Message', FCB_DOMAIN),
                        'placeholder' => __('You are not eligible to download a product. Go to your account settings page and update your email address.', FCB_DOMAIN),
                        'default' => __('You are not eligible to download a product. Go to your account settings page and update your email address,', FCB_DOMAIN),
                        'sub_text' => __('Enter message text that will tell to customer as you\'re not eligible to download their free order.', FCB_DOMAIN),
                        'style' => 'height:100px;'
                    ),
                )
            )
        );
        return $config_big;
    }

}

/**
 *
 * Include JS file
 *
 * */
if (!function_exists('fcb_enqueue_admin_script')) {

    function fcb_enqueue_admin_script() {
        wp_enqueue_script('custom-fcb-wc-script', FCB_PLUGIN_URL . 'assets/js/front.js', array('wp-i18n'), '1.0');
        wp_localize_script('custom-fcb-wc-script', 'custom_ajax_object', array(
            'alert' => __("You're not eligible to download a product. Go to your account settings page and update your email address to any real one.", FCB_DOMAIN),
			'bannedstate' => __('Select Banned States', FCB_DOMAIN)
            )
	    );
    }

}
add_action('admin_enqueue_scripts', 'fcb_enqueue_admin_script');

$this->locale = 'fcb';

new FakeCustomerBlockerSettings(config_big(), $this->locale);
// WooCommrece settings End


/**
 * Contact Form 7 settings Start
 * 
 * @version 1.0.4
 * */
if (!class_exists('FakeCustomerBlockerwpcf7Settings')) {

    class FakeCustomerBlockerwpcf7Settings {

        var $setttings_parameters;
        var $settings_prefix;

        function __construct($parameters, $prefix) {
            $this->setttings_parameters = $parameters;
            $this->setttings_prefix = $prefix;
            add_action('admin_menu', array($this, 'add_menu_item'));
            add_action('init', array($this, 'process_form_parameters_wpcf7'));
        }

        function process_form_parameters_wpcf7() {
            $save_settings_field_for_wpcf7 = !empty($_POST['save_settings_field_for_wpcf7']) ? $_POST['save_settings_field_for_wpcf7'] : '';
            if (wp_verify_nonce($save_settings_field_for_wpcf7, 'save_settings_action')) {
                $options = array();
                foreach ($_POST as $key => $value) {
                    $options[$key] = $value;
                }

                update_option($this->setttings_prefix . '_options', $options);
            }
        }

        function add_menu_item() {

            foreach ($this->setttings_parameters as $single_option) {

                if ($single_option['type'] == 'submenu') {
                    $config = get_option('fcb_wp_options');
                    $check_enable_array = (isset($config['fcbwp-check-enable-for'])) ? $config['fcbwp-check-enable-for'] : array();
                    foreach ($check_enable_array as $selected_permission) {
                        if ($selected_permission == 'WPCF7') {
                            add_submenu_page(
                                    $single_option['parent_slug'], $single_option['page_title'], $single_option['menu_title'], $single_option['capability'], $single_option['menu_slug'], array($this, 'show_settings_wpcf7')
                            );
                        }
                    }
                }
                if ($single_option['type'] == 'option') {
                    add_options_page(
                            $single_option['page_title'], $single_option['menu_title'], $single_option['capability'], $single_option['menu_slug'], array($this, 'show_settings_wpcf7')
                    );
                }
            }
        }

        function show_settings_wpcf7() {
            ?>
            <div class="wrap tw-bs4">
                <h2><?php esc_html_e('Fake Customer Blocker Settings', FCB_DOMAIN); ?></h2>
                <hr/>
                <form class="form-horizontal" method="post" action="">
                    <?php
                        wp_nonce_field('save_settings_action', 'save_settings_field_for_wpcf7');
                        $config = get_option($this->setttings_prefix . '_options');
                    ?>
                    <fieldset>
                        <?php
                        $out = '';

                        foreach ($this->setttings_parameters as $single_page) {
                            foreach ($single_page['parameters'] as $key => $value) {

                                switch ($value['type']) {
                                    case "textarea":
                                        $data_val = (isset($config[$value['name']]) && $config[$value['name']] != '') ? esc_html(stripslashes($config[$value['name']])) : '';
                                        $config_wp = get_option('fcb_wp_options');

                                        if ($value['name'] == 'email_message_for_wpcf7' && in_array('WP', $config_wp['fcbwp-check-enable-for'])) {
                                            $out .= '
                                <div class="form-group">

                                    <label class="control-label" for="' . $value['id'] . '">' . $value['title'] . '</label>
                                    <textarea style="' . $value['style'] . '" class="form-control ' . $value['class'] . '" name="' . $value['name'] . '" id="' . $value['id'] . '" placeholder="' . $value['placeholder'] . '" rows="' . $value['rows'] . '" disabled>' . $data_val . '</textarea>
                                   <h6 style="color:#17a2b8">'. esc_html_e('In your Settings > Fake Customer Blocker, You enable the WordPress option. So, you can not write a message. It will display the message that you set in Settings > Fake Customer Blocker > Global Message For Email.', FCB_DOMAIN).' </h6>
        
                                </div>';
                                        } else {

                                            $out .= '
                            <div class="form-group">
                                <label class="control-label" for="' . $value['id'] . '">' . $value['title'] . '</label>
    
                                  <textarea style="' . $value['style'] . '" class="form-control ' . $value['class'] . '" name="' . $value['name'] . '" id="' . $value['id'] . '" placeholder="' . $value['placeholder'] . '" rows="' . $value['rows'] . '">' . $data_val . '</textarea>
                                  <p class="help-block">' . $value['sub_text'] . '</p>
    
                              </div>';
                                        }
                                        break;
                                }
                            }
                        }
                        echo $out;
                        ?>
                        <div class="form-actions">
                            <button type="submit" class="btn btn-primary"><?php esc_html_e('Save Settings', FCB_DOMAIN); ?></button>
                        </div>
                    </fieldset>
                </form>
            </div>
            <?php
        }

    }

}

/**
 * Return filed array for CF7
 * 
 * @version 1.0.4
 * */
if (!function_exists('config_big_wpcf7')) {

    function config_big_wpcf7() {
        /*
         * add option in backend 
         */
        $config_big_wpcf7 = array(
            array(
                'type' => 'submenu',
                'parent_slug' => 'wpcf7',
                'page_title' => __('Fake Customer Blocker', FCB_DOMAIN),
                'menu_title' => __('Fake Customer Blocker', FCB_DOMAIN),
                'capability' => 'edit_published_posts',
                'menu_slug' => 'fake_customer_blocker',
                'parameters' => array(
                    array(
                        'id' => '',
                        'class' => '',
                        'rows' => '',
                        'name' => 'domain_list_for_wpcf7',
                        'type' => 'textarea',
                        'title' => __('Banned Emails', FCB_DOMAIN),
                        'placeholder' => __('armyspy.com&#x0a;cuvox.de&#x0a;xyz@gmail.com', FCB_DOMAIN),
                        'sub_text' => __('Enter Email one per line', FCB_DOMAIN),
                        'style' => 'height:300px;'
                    ),
                    array(
                        'id' => '',
                        'class' => '',
                        'rows' => '',
                        'name' => 'email_message_for_wpcf7',
                        'type' => 'textarea',
                        'title' => __('Contact Form Message', FCB_DOMAIN),
                        'placeholder' => __('Sorry, you can not use any fake email addresses to make spam orders with the site. Try real email addresses like Gmail, Yahoo, etc.', FCB_DOMAIN),
                        'sub_text' => __('Enter the text message here. It will show on the frontend via the banned Emails.', FCB_DOMAIN),
                        'style' => 'height:100px;'
                    ),
                )
            )
        );
        return $config_big_wpcf7;
    }

}

$this->locale = 'fcb_wpcf7';

new FakeCustomerBlockerwpcf7Settings(config_big_wpcf7(), $this->locale);
// cf7 settings End